from os.path import isfile
from os.path import dirname

version_file = '{}/version.txt'.format(dirname(__file__))

if isfile(version_file):
    with open(version_file) as version_file:
        __version__ = version_file.read().strip()



from setuptools import find_packages
from setuptools import setup

with open('requirements.txt') as f:
    content = f.readlines()
requirements = [x.strip() for x in content if 'git+' not in x]

setup(name='ia_first_package',
      version="1.0",
      description="A test to package sharing",
      packages=find_packages(),
      install_requires=requirements,
      url='https://github.com/iavaq/ia_first_package',
      test_suite='tests',
      # include_package_data: to install data from MANIFEST.in
      include_package_data=True,
      scripts=['scripts/ia_first_package-run'],
      zip_safe=False)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os

def try_me():
    total, used, free = map(int, os.popen('free -t -m').readlines()[-1].split()[1:])
    return f'Your RAM| total: {total}, used: {used}, free: {free}'

if __name__ == "__main__":
    message = try_me()
    print(message)
